summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: 08f8216)
raw | patch | inline | side by side (parent: 08f8216)
author | jhermann <jhermann@57a73879-2fb5-44c3-a270-3262357dd7e2> | |
Mon, 12 Nov 2001 23:17:38 +0000 (23:17 +0000) | ||
committer | jhermann <jhermann@57a73879-2fb5-44c3-a270-3262357dd7e2> | |
Mon, 12 Nov 2001 23:17:38 +0000 (23:17 +0000) |
git-svn-id: http://svn.roundup-tracker.org/svnroot/roundup/trunk@399 57a73879-2fb5-44c3-a270-3262357dd7e2
roundup/init.py | patch | blob | history | |
roundup/install_util.py | patch | blob | history |
--- a/roundup/install_util.py
+++ b/roundup/install_util.py
# BASIS, AND THERE IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
# SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
#
-# $Id: install_util.py,v 1.4 2001-11-12 23:14:40 jhermann Exp $
+# $Id: install_util.py,v 1.5 2001-11-12 23:17:38 jhermann Exp $
import os, sha, shutil
dummy, ext = os.path.splitext(src)
if ext not in digested_file_types:
if copystat:
- return shutil.copy2(srcname, dstname)
+ return shutil.copy2(src, dst)
else:
- return shutil.copyfile(srcname, dstname)
+ return shutil.copyfile(src, dst)
fsrc = None
fdst = None
#
# $Log: not supported by cvs2svn $
+# Revision 1.4 2001/11/12 23:14:40 jhermann
+# Copy function, and proper handling of unknown file types
+#
# Revision 1.3 2001/11/12 22:38:48 richard
# bleah typo
#
diff --git a/roundup/init.py b/roundup/init.py
index f7de005fd8cbd3f714c408fe29839b26a274ed51..7bf27e35227ab58f2bcd52719b00356f47c66b76 100644 (file)
--- a/roundup/init.py
+++ b/roundup/init.py
# BASIS, AND THERE IS NO OBLIGATION WHATSOEVER TO PROVIDE MAINTENANCE,
# SUPPORT, UPDATES, ENHANCEMENTS, OR MODIFICATIONS.
#
-# $Id: init.py,v 1.16 2001-10-09 07:25:59 richard Exp $
+# $Id: init.py,v 1.17 2001-11-12 23:17:38 jhermann Exp $
-import os, shutil, sys, errno
+import os, sys, errno
import roundup.instance, password
+from roundup import install_util
def copytree(src, dst, symlinks=0):
"""Recursively copy a directory tree using copy2().
The destination directory os allowed to exist.
elif os.path.isdir(srcname):
copytree(srcname, dstname, symlinks)
else:
- shutil.copy2(srcname, dstname)
+ install_util.copyDigestedFile(srcname, dstname)
def init(instance_home, template, backend, adminpw):
'''Initialise an instance using the named template and backend.
#
# $Log: not supported by cvs2svn $
+# Revision 1.16 2001/10/09 07:25:59 richard
+# Added the Password property type. See "pydoc roundup.password" for
+# implementation details. Have updated some of the documentation too.
+#
# Revision 1.15 2001/08/07 00:24:42 richard
# stupid typo
#
@@
def copytree(src, dst, symlinks=0):
- """Recursively copy a directory tree using copy2().
+ """Recursively copy a directory tree using copyDigestedFile().
The destination directory os allowed to exist.
elif os.path.isdir(srcname):
index 9477a4920ba0c1b6355e4cb6dca8b2ca27b7065e..ca57d61c1a7057d1f40ad7adf8e1c7db24f4184c 100644 (file)